@@ -189,7 +189,8 @@ describe('Reflect', function () {
     });
 
     it('can return true, even for non-configurable, non-writable properties', function () {
-      var o = {}, desc = {
+      var o = {};
+      var desc = {
         value: 13,
         enumerable: false,
         writable: false,
@@ -280,111 +281,6 @@ describe('Reflect', function () {
     });
   });
 
-  describe('.enumerate()', function () {
-    if (typeof Reflect.enumerate === 'undefined') {
-      return it('exists', function () {
-        expect(Reflect).to.have.property('enumerate');
-      });
-    }
-
-    it('is a function', function () {
-      expect(typeof Reflect.enumerate).to.equal('function');
-    });
-
-    ifFunctionsHaveNamesIt('has the right name', function () {
-      expect(Reflect.enumerate.name).to.equal('enumerate');
-    });
-
-    ifES5It('only includes enumerable properties', function () {
-      var a = Object.create(null, {
-        // Non-enumerable per default.
-        a: { value: 1 }
-      });
-
-      a.b = 2;
-
-      var iter = Reflect.enumerate(a);
-
-      if (hasSymbols && typeof Symbol.iterator === 'symbol') {
-        expect(Symbol.iterator in iter).to.equal(true);
-      }
-
-      expect(Array.from(iter)).to.deep.equal(['b']);
-    });
-
-    it('includes all enumerable properties of prototypes', function () {
-      var Parent = function () {};
-      Parent.prototype.prop = true;
-
-      var Child = function () {};
-      Child.prototype = new Parent();
-      Child.prototype.childProp = true;
-      var child = new Child();
-
-      expect(Array.from(Reflect.enumerate(child)).sort()).to.deep.equal(['prop', 'childProp'].sort());
-    });
-
-    describe('keys determined at first next() call', function () {
-      it('likely does not yield a key added after next()', function () {
-        var obj = { a: 1, b: 2 },
-        iter = Reflect.enumerate(obj);
-
-        expect(iter.next()).to.deep.equal({ value: 'a', done: false });
-
-        obj.c = 3;
-        expect(iter.next()).to.deep.equal({ value: 'b', done: false });
-        expect(iter.next()).to.deep.equal({ value: undefined, done: true });
-      });
-
-      it('may not yield a key added after enumerate(), before next()', function () {
-        var obj = { a: 1, b: 2 };
-        var iter = Reflect.enumerate(obj);
-
-        obj.c = 3;
-        expect(iter.next()).to.deep.equal({ value: 'a', done: false });
-        expect(iter.next()).to.deep.equal({ value: 'b', done: false });
-        var thirdResult = iter.next();
-        // Webkit's implementation of Reflect.enumerate locks the keys at iterator creation
-        if (thirdResult.done) {
-          expect(iter.next()).to.deep.equal({ value: undefined, done: true });
-        } else {
-          expect(iter.next()).to.deep.equal({ value: 'c', done: false });
-          expect(iter.next()).to.deep.equal({ value: undefined, done: true });
-        }
-      });
-
-      it('does not yield an unyielded key deleted after first next()', function () {
-        var obj = { a: 1, b: 2 };
-        var iter = Reflect.enumerate(obj);
-
-        expect(iter.next()).to.deep.equal({ value: 'a', done: false });
-        delete obj.b;
-        expect(iter.next()).to.deep.equal({ value: undefined, done: true });
-      });
-    });
-
-    describe('enumeration order', function () {
-      it('enumerates own keys before prototype keys', function () {
-        var Foo = function Foo(arg) {
-          this.b = arg;
-          this[2] = arg;
-        };
-        Foo.prototype.a = 'bar';
-        Foo.prototype.c = 'bar';
-        Foo.prototype[1] = 'bar';
-        var foo = new Foo(42);
-
-        var iter = Reflect.enumerate(foo);
-        expect(iter.next()).to.deep.equal({ value: '2', done: false });
-        expect(iter.next()).to.deep.equal({ value: 'b', done: false });
-        expect(iter.next()).to.deep.equal({ value: '1', done: false });
-        expect(iter.next()).to.deep.equal({ value: 'a', done: false });
-        expect(iter.next()).to.deep.equal({ value: 'c', done: false });
-        expect(iter.next()).to.deep.equal({ value: undefined, done: true });
-      });
-    });
-  });
-
   describeIfES5('.get()', function () {
     if (typeof Reflect.get === 'undefined') {
       return it('exists', function () {
